/*
 *  Jomar3D, a lobster-running-to-catch game.
 *  Copyright (C) 2006-2008 Jonathan Michalon <studios.chalmion@no-log.org>.
 * 
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#ifndef JOMAR3D_H
#define JOMAR3D_H


#ifndef DEBUG
# define DEBUG 0          /* 0: false, no debug   1: first level   2: a very long poem every step */
#endif

#ifndef USEGLEW
# define USEGLEW 0        /* whether we use glew, needed to use OpenGL extensions */
#endif

#define MYFREEGLUT 0      /* NOT WORKING whether we have freeglut or the basic glut (interesting options) */

/* Default directory definition : when not given by make */
#ifndef DATADIR
# define DATADIR "."
#endif


/* number of martians */
#if (DEBUG)
# define NMARTIANS 1
#else
# define NMARTIANS 10
#endif

/* field of view of the Martians (squares) */
#define martview 3

/* size of the ground (steps) */
#define T_X 40
#define T_Y 30
/* size of each square of the ground (OpenGL units) */
#define T_C 70.
/* height of the wells */
#define T_H 80.

/* Define the lobster move's duration (millisecond) */
#define LM_S 250.      /* straight forward/backward */
#define LM_T 500.      /* turning */
#define LM_E 100.      /* eating */
#define LM_A 600.      /* after eating */
#define LM_B 99.       /* boosted */

/* Define bomb explosion duration (millisecond)*/
#define EXPLODE 5000.

#ifndef FALSE
# define FALSE 0
#endif
#ifndef TRUE
# define TRUE 1
#endif


enum
{
  T_EMPTY = 0,                  /**< Empty */
  T_LOBSTER_FORWARD = 1,        /**< y+ */
  T_LOBSTER_RIGHT,              /**< x+ */
  T_LOBSTER_BACKWARD,           /**< y- */
  T_LOBSTER_LEFT,               /**< x- */
  T_MARTIAN_FORWARD = 11,       /**< y+ */
  T_MARTIAN_RIGHT,              /**< x+ */
  T_MARTIAN_BACKWARD,           /**< y- */
  T_MARTIAN_LEFT,               /**< x- */
  T_WALL,                       /**< Wall */
  T_BOMB,                       /**< Bomb */
  T_LOCKED                      /**< Position locked (init) */
};

#endif /* guard */
